# Pyutter

## What is it

Pyutter is a python package that allows easy and fast simple front end development with python.

## Main Features

* Basic material component Card, Chip and Appbar
* Layout components Column, Row, Grid ...
* Ability to return server side function using Function and State

## How to get it

`pip install plutter`

## Dependency

[FastAPI](https://fastapi.tiangolo.com/)

[uvicorn](https://www.uvicorn.org/)